# Generated by roxygen2: do not edit by hand

export("archive_retries<-")
export("archive_timing<-")
export("dep_repos<-")
export("dl_method<-")
export("logfun<-")
export("manifest<-")
export("manifest_df<-")
export("sh_init_script<-")
export("shell_timing<-")
export("subdir<-")
export("versions_df<-")
export(.libPaths2)
export(BiocSVNManifest)
export(BiocVers)
export(GithubManifest)
export(ManifestRow)
export(PkgManifest)
export(RepoSubset)
export(SessionManifest)
export(SwitchrCtx)
export(SwitchrParam)
export(addPkg)
export(archive_retries)
export(archive_timing)
export(biocReposForVers)
export(branch)
export(checkIsPkgDir)
export(cranPkgVersManifest)
export(currentCompEnv)
export(defaultRepos)
export(dep_repos)
export(dl_method)
export(errorOrNonZero)
export(fileFromFileURL)
export(findNewestPkgInds)
export(findNewestPkgRows)
export(findPkgDir)
export(findPkgVersionInRepo)
export(flushSession)
export(full_libpaths)
export(getPkgDir)
export(gotoVersCommit)
export(graceful_inet)
export(head)
export(install_packages)
export(lazyRepo)
export(libManifest)
export(library_paths)
export(loadGRAN)
export(loadManifest)
export(locatePkgVersion)
export(location)
export(logfun)
export(makeBiocSVNURL)
export(makeFileURL)
export(makeLibraryCtx)
export(makeManifest)
export(makePkgCheckout)
export(makePkgDir)
export(makeSeedMan)
export(makeSource)
export(manifest)
export(manifestFromCheckoutDir)
export(manifest_df)
export(normalizePath2)
export(notrack)
export(nrow)
export(packages)
export(parseSessionInfoString)
export(pkgname)
export(publishManifest)
export(rVersionManifest)
export(removeLib)
export(sh_init_script)
export(shell_timing)
export(subdir)
export(switchBack)
export(switchDeps)
export(switchTo)
export(switchrBaseDir)
export(switchrDontUnload)
export(switchrManifest)
export(switchrNoUnload)
export(system_w_init)
export(tail)
export(update_PACKAGES)
export(versions_df)
export(warning2)
exportClasses(BiocSource)
exportClasses(CRANSource)
exportClasses(CVSSource)
exportClasses(GitSource)
exportClasses(GithubSource)
exportClasses(LocalSource)
exportClasses(PkgManifest)
exportClasses(PkgSource)
exportClasses(SVNSource)
exportClasses(SessionManifest)
exportClasses(SwitchrParam)
exportClasses(TarballSource)
exportClasses(parsedSessionInfo)
exportMethods(c)
exportMethods(head)
exportMethods(location)
exportMethods(tail)
import(RCurl)
import(RJSONIO)
import(methods)
importFrom(stats,setNames)
importFrom(tools,md5sum)
importFrom(tools,write_PACKAGES)
importFrom(utils,available.packages)
importFrom(utils,capture.output)
importFrom(utils,chooseCRANmirror)
importFrom(utils,compareVersion)
importFrom(utils,contrib.url)
importFrom(utils,download.file)
importFrom(utils,download.packages)
importFrom(utils,installed.packages)
importFrom(utils,read.table)
importFrom(utils,sessionInfo)
importFrom(utils,untar)
importFrom(utils,unzip)
importFrom(utils,write.table)
